===================
Mensajes Masivos SMS
===================

api de modelos de microsip para django

Install or update
-------

### latest version ###
```
pip install --upgrade django_msp_sms
```
### An specific release version ###
```
pip install --upgrade django_msp_sms == [version]